@@ -24,12 +24,10 @@ class Subtitle:
         elif isinstance(filepath, str):
             self.filepath: AnyStr = filepath
             self.file: AnyStr = Path(filepath).stem
-        else:
-            raise TypeError('"{}" is not of type str'.format(filepath))
         self.raw_text: AnyStr = self.get_text()
         self.dialogues: List = []
 
-    def get_text(self) -> AnyStr:
+    def get_text(self) -> str:
         """
         Reads the file and returns the complete contents
         :return: File contents
